import { computed, watch } from "vue";
import { useStore } from "vuex";

export default {
  props: {
    ids: {
      type: Array,
      default: () => [],
    },
    className: {
      type: String,
      default: "",
    },
    labelKey: {
      type: String,
      default: "name",
    },
    resource: String,
    api: Object,
    plain: {
      type: Boolean,
      default: false,
    },
    joinString: {
      type: String,
      default: "、",
    },
  },
  setup(props) {
    const { state, dispatch } = useStore();

    const items = computed(() =>
      state.items.data[props.resource]
        ? state.items.data[props.resource][props.ids.join(",")]
        : {}
    );

    watch(
      () => props.ids,
      async (newVal) => {
        if (newVal && newVal.length) {
          await dispatch("items/getItems", {
            resource: props.resource,
            Api: props.api,
            ids: newVal,
          });
        } else {
          items.value = [];
        }
      },
      { immediate: true, deep: true }
    );

    return {
      items,
    };
  },
};
